@@ -1,5 +1,7 @@
 from runbox import models
 from .docker.docker_api import DockerExecutor
 from .docker.sandbox import DockerSandbox
+from .docker.mount import Mount
+from .docker.sandbox_builder import SandboxBuilder
 
 __version__ = '0.3.1'
